@@ -1,8 +1,9 @@
 use crate::mail::Mailer;
 
 pub fn send(mailer: &Mailer, to_email: &str, link: &str) {
-  let subject = "Reset Password Instructions)";
-  let text = format!(r#"
+    let subject = "Reset Password Instructions)";
+    let text = format!(
+        r#"
 (This is an automated message.)
 
 Hello,
@@ -11,8 +12,11 @@ Someone requested a password reset for the account associated with this email.
 Please visit this link to reset your password:
 {link}
 (valid for 24 hours)
-"#, link=link);
-  let html = format!(r#"
+"#,
+        link = link
+    );
+    let html = format!(
+        r#"
 (This is an automated message.)
 
 Hello,
@@ -21,7 +25,9 @@ Someone requested a password reset for the account associated with this email.
 Please visit this link to reset your password:
 {link}
 (valid for 24 hours)
-"#, link=link);
+"#,
+        link = link
+    );
 
-  mailer.send(to_email, &subject, &text, &html);
-}
\ No newline at end of file
+    mailer.send(to_email, &subject, &text, &html);
+}
